@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010_001;
 
-our $VERSION = '0.12';
+our $VERSION = '0.20';
 
 use YAML ();
 use Class::Load ();
@@ -324,6 +324,25 @@ whereas done on localhost without it.
 Remote login username is retrieved by C<get 'user'> or C<`whoami`>
 command. Set appropriate username in advance if needed.
 
+=head2 Configuration Variables
+
+Cinnamon configuration is managed by set function.  You can customize following variables.
+
+=head3 user
+
+user name which is used for login to server.
+
+=head3 concurrency
+
+Max number of concurrent execution of tasks.  the task which is not specified concurrency, is executed in parallel by all the hosts.
+
+=over 4
+
+    set concurrency => {
+        restart        => 1,
+        'server:setup' => 2,
+    };
+
 =back
 
 =head1 REPOSITORY
